@@ -1,7 +1,7 @@
 use std::fmt::Debug;
 
 use crate::core::checkpoint::{CheckpointFunction, CheckpointHandle, FunctionSnapshotContext};
-use crate::core::element::{Element, Record};
+use crate::core::element::{Element, FnSchema, Record};
 use crate::core::properties::Properties;
 use crate::core::runtime::{CheckpointId, OperatorId, TaskId};
 use crate::dag::execution_graph::{ExecutionEdge, ExecutionNode};
@@ -22,6 +22,9 @@ pub struct Context {
     pub completed_checkpoint_id: Option<CheckpointId>,
     pub checkpoint_handle: Option<CheckpointHandle>,
 
+    pub input_schema: FnSchema,
+    pub output_schema: FnSchema,
+
     pub(crate) children: Vec<(ExecutionNode, ExecutionEdge)>,
     pub(crate) parents: Vec<(ExecutionNode, ExecutionEdge)>,
 }
@@ -127,6 +130,8 @@ where
     fn daemon(&self) -> bool {
         false
     }
+
+    fn schema(&self, input_schema: FnSchema) -> FnSchema;
 }
 
 pub trait OutputFormat
@@ -154,6 +159,10 @@ where
     // fn prepare_commit(&mut self) {}
     // fn commit(&mut self) {}
     // fn abort(&mut self) {}
+
+    fn schema(&self, _input_schema: FnSchema) -> FnSchema {
+        FnSchema::Empty
+    }
 }
 
 pub trait FlatMapFunction
@@ -167,6 +176,8 @@ where
         Box::new(ElementIterator::new(iterator))
     }
     fn close(&mut self) -> crate::core::Result<()>;
+
+    fn schema(&self, input_schema: FnSchema) -> FnSchema;
 }
 
 pub trait FilterFunction
@@ -185,6 +196,8 @@ where
     fn open(&mut self, context: &Context) -> crate::core::Result<()>;
     fn get_key(&self, record: &mut Record) -> Record;
     fn close(&mut self) -> crate::core::Result<()>;
+
+    fn key_schema(&self, input_schema: FnSchema) -> FnSchema;
 }
 
 pub trait ReduceFunction
@@ -195,6 +208,8 @@ where
     ///
     fn reduce(&self, value: Option<&mut Record>, record: &mut Record) -> Record;
     fn close(&mut self) -> crate::core::Result<()>;
+
+    fn schema(&self, input_schema: FnSchema) -> FnSchema;
 }
 
 pub(crate) trait BaseReduceFunction
@@ -205,6 +220,8 @@ where
     fn reduce(&mut self, key: Record, record: Record);
     fn drop_state(&mut self, watermark_timestamp: u64) -> Vec<Record>;
     fn close(&mut self) -> crate::core::Result<()>;
+
+    fn value_schema(&self, key_schema: FnSchema) -> FnSchema;
 }
 
 pub trait CoProcessFunction
@@ -222,6 +239,8 @@ where
         record: Record,
     ) -> Box<dyn Iterator<Item = Record>>;
     fn close(&mut self) -> crate::core::Result<()>;
+
+    fn schema(&self, input_schema: FnSchema) -> FnSchema;
 }
 
 pub(crate) struct ElementIterator<T>
