@@ -25,8 +25,6 @@ pub(crate) fn build_cluster_descriptor(
                 .iter()
                 .map(|stream_node| OperatorDescriptor {
                     operator_id: stream_node.id,
-                    input_schema: stream_node.input_schema.clone(),
-                    output_schema: stream_node.output_schema.clone(),
                     checkpoint_id: CheckpointId::default(),
                     completed_checkpoint_id: None,
                     checkpoint_handle: None,
